@@ -24,6 +24,7 @@
 namespace KCalendarCore
 {
 class FreeBusy;
+class ICalFormatPrivate;
 class Incidence;
 class IncidenceBase;
 class RecurrenceRule;
@@ -65,11 +66,16 @@ public:
     */
     bool save(const Calendar::Ptr &calendar, const QString &fileName) override;
 
+#if KCALENDARCORE_BUILD_DEPRECATED_SINCE(5, 97)
     /**
       @copydoc
       CalFormat::fromString()
     */
-    bool fromString(const Calendar::Ptr &calendar, const QString &string, bool deleted = false, const QString &notebook = QString()) override;
+    KCALENDARCORE_DEPRECATED_VERSION(5, 97, "use fromString(const Calendar::Ptr &calendar, const QString &string, const QString &notebook)")
+    bool fromString(const Calendar::Ptr &calendar, const QString &string, bool deleted, const QString &notebook) override;
+#endif
+    // make CalFromat::fromString(const Calendar::Ptr &calendar, const QString&, const QString&) visible here as well
+    using CalFormat::fromString;
 
     /**
       Parses a string, returning the first iCal component as an Incidence.
@@ -221,17 +227,21 @@ public:
     Q_REQUIRED_RESULT QByteArray timeZoneId() const;
 
 protected:
+#if KCALENDARCORE_BUILD_DEPRECATED_SINCE(5, 96)
     /**
       @copydoc
       IncidenceBase::virtual_hook()
     */
     void virtual_hook(int id, void *data) override;
+#endif
 
 private:
     //@cond PRIVATE
     Q_DISABLE_COPY(ICalFormat)
-    class Private;
-    Private *const d;
+    Q_DECLARE_PRIVATE(ICalFormat)
+#if KCALENDARCORE_BUILD_DEPRECATED_SINCE(5, 96)
+    void *unused; // former dptr, just kept for ABI compatibility
+#endif
     //@endcond
 };
 
